@@ -18,7 +18,7 @@ NULL
 #' @param x An R vector you want to turn into a Crunch variable
 #' @param ... Additional metadata fields for the variable, such as "name" and
 #' "description". See the [API documentation](
-#' http://docs.crunch.io/endpoint-reference/endpoint-variable.html#post-catalog)
+#' https://docs.crunch.io/endpoint-reference/endpoint-variable.html#post-catalog)
 #' for a complete list of valid attributes.
 #' @return A `VariableDefinition` object. To add this to a dataset, either
 #' assign it into the dataset (like `ds$newvar <- toVariable(...)`) or call
@@ -42,7 +42,7 @@ setGeneric("toVariable", function(x, ...) standardGeneric("toVariable"))
 
 #' @rdname toVariable
 #' @export
-setMethod("toVariable", "CrunchExpr", function(x, ...) {
+setMethod("toVariable", "CrunchVarOrExpr", function(x, ...) {
     structure(list(derivation = zcl(x), ...), class = "VariableDefinition")
 })
 
@@ -75,8 +75,22 @@ setMethod("toVariable", "Date", function(x, ...) {
 #' @rdname toVariable
 #' @export
 setMethod("toVariable", "POSIXt", function(x, ...) {
+    # R uses truncation rather than rounding for formatting ms, so numeric
+    # precision can cause us to be off. Get 4 digits and round them
+
+    # Upload as local time, even though it will be converted to UTC in crunch's database
+    # this means the "print" value of the date (eg when we get the date back, it'll be
+    # stored as UTC, so 1AM CST becomes 1AM UTC)
+    tzone <- attr(x, "tzone")
+    values <- strftime(x, "%Y-%m-%dT%H:%M:%OS4", tz = tzone)
+    values <- paste0(
+        substr(values, 1, 20),
+        as.character(round(as.numeric(substr(values, 21, 26)) / 10))
+    )
+    values[is.na(x)] <- ""
+
     return(VariableDefinition(
-        values = strftime(x, "%Y-%m-%dT%H:%M:%OS3"),
+        values = values,
         type = "datetime",
         resolution = "ms", ...
     ))
