@@ -4,7 +4,9 @@
 #' variables. These are evaluated in the order they are supplied in the list
 #' as the `cases` argument (they proceed in an IF, ELSE IF, ELSE IF, ..., ELSE
 #' fashion); the first one that matches selects the corresponding value from
-#' the case list.
+#' the case list. `caseExpr()` is a version that returns an expression that
+#' could be used when creating complex variables, see \code{\link{expressions}} for
+#' more details.
 #'
 #' There are two ways to specify cases, but you must pick only one (note these
 #' two will produce the same case variable):
@@ -69,20 +71,34 @@ makeCaseVariable <- function(..., cases, data = NULL, name) {
     ## Gather the new variable's metadata fields (and possibly expressions)
     # -1 to remove the list primative
     dots <- as.list(substitute(list(...)))[-1L]
-    casevar <- lapply(dots, evalSide, dat = data, eval_env = parent.frame())
-    casevar$name <- name
+    dots <- lapply(dots, evalSide, dat = data, eval_env = parent.frame())
     is_expr <- function(x) {
         inherits(x, "CrunchLogicalExpr") || x %in% magic_else_string
     }
-    exprs <- Filter(is_expr, casevar)
+
+    args <- Filter(is_expr, dots)
+    if (!missing(cases)) {
+        cases <- evalSide(substitute(cases), data, parent.frame())
+        args$cases <- cases
+    }
+    derivation <- do.call(caseExpr, args)
+    meta <- Filter(Negate(is_expr), dots)
+
+    do.call(VarDef, c(meta, list(name = name, data = derivation)))
+}
+
+#' @rdname makeCaseVariable
+#' @export
+caseExpr <- function(..., cases) {
+    exprs <- list(...)
+
     if (length(exprs) > 0) {
         if (missing(cases)) {
             ## Remove the expressions from the variable definition
-            casevar <- Filter(Negate(is_expr), casevar)
             cases <- mapply(function(e, n) list(
-                    name = n,
-                    expression = e
-                ),
+                name = n,
+                expression = e
+            ),
             e = exprs, n = names(exprs),
             SIMPLIFY = FALSE, USE.NAMES = FALSE
             )
@@ -102,7 +118,6 @@ makeCaseVariable <- function(..., cases, data = NULL, name) {
         )
     }
 
-    cases <- evalSide(substitute(cases), data, parent.frame())
     cases <- ensureValidCases(cases)
 
     # create the new categorical variable
@@ -110,22 +125,20 @@ makeCaseVariable <- function(..., cases, data = NULL, name) {
         value = list(
             class = "categorical",
             categories = lapply(cases, function(case) {
-                case[c("id", "name", "numeric_value", "missing")]
+                date_name <- if ("date" %in% names(case)) "date" else NULL
+                case[c("id", "name", "numeric_value", "missing", date_name)]
             })
         )
     )
     new_cat_ids <- vapply(cases, vget("id"), integer(1))
     new_cat <- list(column = I(new_cat_ids), type = new_cat_type)
 
-    casevar$derivation <- zfunc("case", new_cat)
-
-    # add case_expressions, remove nulls (should only be from the else case)
+    # remove nulls from case expressions (should only be from the else case)
     case_exprs <- lapply(cases, function(x) zcl(x$expression))
     case_exprs <- Filter(Negate(is.null), case_exprs)
-    casevar$derivation$args <- c(casevar$derivation$args, case_exprs)
-
-    class(casevar) <- "VariableDefinition"
-    return(casevar)
+    # TODO: ensure filters are the same
+    derivation <- do.call(zfunc, c(list("case", new_cat), case_exprs))
+    CrunchExpr(expression = derivation)
 }
 
 magic_else_string <- "else"
@@ -168,6 +181,12 @@ ensureValidCases <- function(cases) {
         )
     }
 
+
+    all_dates <- lapply(cases, vget("date"))
+    if (all(lengths(all_dates) == 0)) {
+        cases <- lapply(cases, function(case) modifyList(case, list(date = NULL)))
+    }
+
     return(cases)
 }
 
@@ -193,7 +212,7 @@ ensureValidCase <- function(case) {
 
     defaults <- list(
         id = NULL, name = NULL, expression = NULL,
-        numeric_value = NULL, missing = FALSE
+        numeric_value = NULL, missing = FALSE, date = NULL
     )
     wrong_case_names <- setdiff(names(case), names(defaults))
     if (is.null(wrong_case_names) || "" %in% names(case)) {
@@ -232,6 +251,9 @@ ensureValidCase <- function(case) {
     if (!is.character(case$name)) {
         halt("a case's name must be a character")
     }
+    if (!is.null(case$date) && !is.character(case$date)) {
+        halt("a case's date must be a character")
+    }
 
     if (is_else_case(case)) {
         case$expression <- NULL
