@@ -23,7 +23,8 @@ setGeneric("variables<-", function(x, value) standardGeneric("variables<-"))
 #' @rdname variables
 setGeneric("allVariables", function(x) standardGeneric("allVariables"))
 #' @rdname variables
-setGeneric("allVariables<-",
+setGeneric(
+    "allVariables<-",
     function(x, value) standardGeneric("allVariables<-")
 )
 
@@ -51,10 +52,16 @@ setDatasetVariables <- function(x, value) {
 
 #' @rdname variables
 #' @export
-setMethod("variables", "CrunchDataset", function(x) active(allVariables(x)))
+setMethod("variables", "CrunchDataset", function(x) {
+    variables <- allVariables(x)
+    variables <- variables[!(aliases(variables) %in% hiddenVariables(x, "alias"))]
+    variables <- variables[!(aliases(variables) %in% privateVariables(x, "alias"))]
+    variables
+})
 #' @rdname variables
 #' @export
-setMethod("variables<-", c("CrunchDataset", "VariableCatalog"),
+setMethod(
+    "variables<-", c("CrunchDataset", "VariableCatalog"),
     setDatasetVariables
 )
 #' @rdname variables
@@ -62,7 +69,8 @@ setMethod("variables<-", c("CrunchDataset", "VariableCatalog"),
 setMethod("allVariables", "CrunchDataset", function(x) x@variables)
 #' @rdname variables
 #' @export
-setMethod("allVariables<-", c("CrunchDataset", "VariableCatalog"),
+setMethod(
+    "allVariables<-", c("CrunchDataset", "VariableCatalog"),
     setDatasetVariables
 )
 
