@@ -141,7 +141,7 @@ with_mock_crunch({
         mr_var <- variables(catarray_x_mr)[[3]]
         expect_equal(
             aliases(subvariables(mr_var)),
-            c("food_opinion#", "rest_opinion#", "play_opinion#")
+            c("food_opinion__1", "rest_opinion__1", "play_opinion__1")
         )
         expect_equal(
             names(subvariables(mr_var)),
