@@ -6,29 +6,29 @@ with_mock_crunch({
 
     test_that("cut labels are generated correcty", {
         expect_identical(
-            generateCutLabels(5, c(2.111111, 3, 4, 5), 4, FALSE, FALSE),
+            generateNumCutLabels(5, c(2.111111, 3, 4, 5), 4, FALSE, FALSE),
             c("[2.1111,3)", "[3,4)", "[4,5)")
         )
         expect_identical(
-            generateCutLabels(2, c(2.111111, 3, 4, 5), 4, FALSE, FALSE),
+            generateNumCutLabels(2, c(2.111111, 3, 4, 5), 4, FALSE, FALSE),
             c("[2.1,3)", "[3,4)", "[4,5)")
         )
         expect_identical(
-            generateCutLabels(2, c(2, 3, 4, 5), 4, FALSE, FALSE),
+            generateNumCutLabels(2, c(2, 3, 4, 5), 4, FALSE, FALSE),
             c("[2,3)", "[3,4)", "[4,5)")
         )
         expect_identical(
-            generateCutLabels(5, c(2.111111, 3, 4, 5), 4, TRUE, TRUE),
+            generateNumCutLabels(5, c(2.111111, 3, 4, 5), 4, TRUE, TRUE),
             c("[2.1111,3]", "(3,4]", "(4,5]")
         )
         expect_identical(
-            generateCutLabels(5, c(2.111111, 3, 4, 5), 4, FALSE, TRUE),
+            generateNumCutLabels(5, c(2.111111, 3, 4, 5), 4, FALSE, TRUE),
             c("[2.1111,3)", "[3,4)", "[4,5]")
         )
         # if the breaks are all the same at up to 12 decimal points
-        # generateCutLabels will use Range_n lagles.
+        # generateNumCutLabels will use Range_n lagles.
         expect_identical(
-            generateCutLabels(
+            generateNumCutLabels(
                 5,
                 c(
                     2.111111111111, 2.111111111112,
@@ -52,7 +52,6 @@ with_mock_crunch({
 
         ##################### EXPECTED OUTPUT ######################################
         basic_output <- list(
-            name = "new_var",
             derivation = list(
                 `function` = "case",
                 args = list(
@@ -91,14 +90,14 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -1.4998629)
+                                    structure(list(value = -1.4998629), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             )
                         )
@@ -110,14 +109,14 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             )
                         )
@@ -129,25 +128,25 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 1.6693629)
+                                    structure(list(value = 1.6693629), class = "zcl")
                                 )
                             )
                         )
                     )
                 )
-            )
+            ),
+            name = "new_var"
         )
 
 
         right_false <- list(
-            name = "new_var",
             derivation = list(
                 `function` = "case",
                 args = list(
@@ -186,13 +185,13 @@ with_mock_crunch({
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -1.4998629)
+                                    structure(list(value = -1.4998629), class = "zcl")
                                 )
                             ), list(
                                 `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             )
                         )
@@ -204,14 +203,14 @@ with_mock_crunch({
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             )
                         )
@@ -223,23 +222,23 @@ with_mock_crunch({
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             ), list(
                                 `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 1.6693629)
+                                    structure(list(value = 1.6693629), class = "zcl")
                                 )
                             )
                         )
                     )
                 )
-            )
+            ),
+            name = "new_var"
         )
 
         set_breaks <- list(
-            name = "new_var",
             derivation = list(
                 `function` = "case",
                 args = list(
@@ -272,14 +271,14 @@ with_mock_crunch({
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -1.4967)
+                                    structure(list(value = -1.4967), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0)
+                                    structure(list(value = 0), class = "zcl")
                                 )
                             )
                         )
@@ -291,24 +290,24 @@ with_mock_crunch({
                                 `function` = ">=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0)
+                                    structure(list(value = 0), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 1.6662)
+                                    structure(list(value = 1.6662), class = "zcl")
                                 )
                             )
                         )
                     )
                 )
-            )
+            ),
+            name = "new_var"
         )
 
         dig_lab <- list(
-            name = "new_var",
             derivation = list(
                 `function` = "case",
                 args = list(
@@ -347,14 +346,14 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -1.4998629)
+                                    structure(list(value = -1.4998629), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             )
                         )
@@ -366,14 +365,14 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = -0.4424)
+                                    structure(list(value = -0.4424), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             )
                         )
@@ -385,20 +384,21 @@ with_mock_crunch({
                                 `function` = ">",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 0.6119)
+                                    structure(list(value = 0.6119), class = "zcl")
                                 )
                             ),
                             list(
                                 `function` = "<=",
                                 args = list(
                                     list(variable = "https://app.crunch.io/api/datasets/1/variables/birthyr/"), # nolint
-                                    list(value = 1.6693629)
+                                    structure(list(value = 1.6693629), class = "zcl")
                                 )
                             )
                         )
                     )
                 )
-            )
+            ),
+            name = "new_var"
         )
 
 
@@ -470,6 +470,158 @@ with_mock_crunch({
             paste0(sQuote("breaks"), " must be unique")
         )
     })
+
+
+    test_that("isoweekyear gets weeks dates right", {
+        expect_equal(
+            isoweekyear(as.Date(c("2020-01-01", "2020-01-08"))),
+            c("2020-W01", "2020-W02")
+        )
+        # crossing year boundary
+        expect_equal(
+            isoweekyear(as.Date(c("2016-01-01", "2017-01-01", "2019-12-30"))),
+            c("2015-W53", "2016-W52", "2020-W01")
+        )
+    })
+
+    test_that("parse_break_units works", {
+        expect_equal(parse_break_units("month"), list(quantity = 1, unit = "month"))
+        expect_equal(parse_break_units("weeks"), list(quantity = 1, unit = "week"))
+        expect_equal(parse_break_units("7 days"), list(quantity = 7, unit = "day"))
+    })
+
+    test_that("cut date catdates are correct", {
+        expect_equal(
+            generateCatdates(
+                "week",
+                as.Date(c("2020-02-03", "2020-02-10", "2020-02-18"))
+                ),
+            c("2020-W06", "2020-W07", "2020-W08")
+        )
+
+        expect_equal(
+            generateCatdates(
+                "month",
+                as.Date(c("2020-02-03", "2020-03-10", "2020-04-18"))
+            ),
+            c("2020-02", "2020-03", "2020-04")
+        )
+
+        date_seq <- as.POSIXct(
+            c("2020-01-01 00:01:00", "2020-01-04 00:01:00", "2020-01-08 00:01:00"),
+            tz = "UTC"
+        )
+        expect_equal(
+            generateCatdates(date_seq, date_seq),
+            c("2020-01-01,2020-01-03", "2020-01-04,2020-01-07")
+        )
+    })
+
+    test_that("cut date labels are correct", {
+        expect_equal(
+            generateDateCutLabels(
+                "week",
+                as.Date(c("2020-02-03", "2020-02-10", "2020-02-18"))
+            ),
+            c("2020/02/03 - 2020/02/09", "2020/02/10 - 2020/02/17", "2020/02/18 - 2020/02/24")
+        )
+
+        expect_equal(
+            generateDateCutLabels(
+                "month",
+                as.Date(c("2020-02-01", "2020-03-01", "2020-04-01"))
+            ),
+            c("2020/02/01 - 2020/02/29", "2020/03/01 - 2020/03/31", "2020/04/01 - 2020/04/30")
+        )
+
+        date_seq <- as.POSIXct(
+            c("2020-01-01 00:01:00", "2020-01-04 00:01:00", "2020-01-08 00:01:00"),
+            tz = "UTC"
+        )
+        expect_equal(
+            generateDateCutLabels(date_seq, date_seq),
+            c("2020/01/01 - 2020/01/03", "2020/01/04 - 2020/01/07")
+        )
+    })
+
+    test_that("cut date returns expected output", {
+        ds_catdate <- loadDataset("cat date test")
+
+        simple_date_cut <- structure(list(
+            derivation = list(
+                `function` = "case",
+                args = list(
+                    list(
+                        column = structure(1:2, class = "AsIs"),
+                        type = list(
+                            value = list(
+                                class = "categorical",
+                                categories = list(
+                                    list(
+                                        id = 1L,
+                                        name = "2020/01/01 - 2020/01/31",
+                                        numeric_value = NULL,
+                                        missing = FALSE,
+                                        date = "2020-01"
+                                    ),
+                                    list(
+                                        id = 2L,
+                                        name = "2020/02/01 - 2020/02/29",
+                                        numeric_value = NULL,
+                                        missing = FALSE,
+                                        date = "2020-02"
+                                    )
+                                )
+                            )
+                        )
+                    ), list(
+                        `function` = "and",
+                        args = list(
+                            list(
+                                `function` = ">=",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/b9d811/variables/000001/"), # nolint
+                                    structure(list(value = "2020-01-01"), class = "zcl")
+                                )
+                            ),
+                            list(
+                                `function` = "<",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/b9d811/variables/000001/"), # nolint
+                                    structure(list(value = "2020-02-01"), class = "zcl")
+                                )
+                            )
+                        )
+                    ),
+                    list(
+                        `function` = "and",
+                        args = list(
+                            list(
+                                `function` = ">=",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/b9d811/variables/000001/"), # nolint
+                                    structure(list(value = "2020-02-01"), class = "zcl")
+                                    )
+                                ),
+                            list(
+                                `function` = "<",
+                                args = list(
+                                    list(variable = "https://app.crunch.io/api/datasets/b9d811/variables/000001/"), # nolint
+                                    structure(list(value = "2020-03-01"), class = "zcl")
+                                    )
+                                )
+                            )
+                        )
+                    )
+                ),
+            name = "cut month"
+            ), class = "VariableDefinition")
+
+        expect_equal(
+            cut(ds_catdate$true_date, "month", name = "cut month"),
+            simple_date_cut
+        )
+    })
 })
 
 with_test_authentication({
