@@ -13,6 +13,11 @@ with_mock_crunch({
         expect_identical(datasetReference(multitables(ds)[[1]]), ds_url)
         expect_null(datasetReference(1))
         expect_null(datasetReference("not a ds url"))
-        expect_identical(datasetReference("https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1"), ds_url)
+        expect_identical(
+            datasetReference(
+                "https://app.crunch.io/api/datasets/1/variables/mymrset/subvariables/subvar1"
+            ),
+            ds_url
+        )
     })
 })
