@@ -93,17 +93,22 @@ with_mock_crunch({
             out@index <- list()
             return(out)
         },
-        test_that("Sharing works even if the PermissionCatalog is empty (as with a project-owned dataset)", {
-            expect_length(permissions(ds), 0)
-            expect_PATCH(
-                share(ds, "lauren.ipsum@crunch.io",
-                    notify = FALSE
-                ),
-                "https://app.crunch.io/api/datasets/1/permissions/",
-                '{"lauren.ipsum@crunch.io":{"dataset_permissions":',
-                '{"edit":false,"view":true}},"send_notification":false}'
-            )
-        })
+        test_that(
+            paste0(
+                "Sharing works even if the PermissionCatalog is empty (as with ",
+                "a project-owned dataset)"
+            ), {
+                expect_length(permissions(ds), 0)
+                expect_PATCH(
+                    share(ds, "lauren.ipsum@crunch.io",
+                        notify = FALSE
+                    ),
+                    "https://app.crunch.io/api/datasets/1/permissions/",
+                    '{"lauren.ipsum@crunch.io":{"dataset_permissions":',
+                    '{"edit":false,"view":true}},"send_notification":false}'
+                )
+            }
+        )
     )
 })
 
